@@ -21,7 +21,7 @@
  */
 
 /**
- * SECTION:ges-clip
+ * SECTION:gesclip
  * @short_description: Base Class for objects in a GESLayer
  *
  * A #GESClip is a 'natural' object which controls one or more
@@ -95,7 +95,7 @@ _get_priority_range (GESContainer * container, guint32 * min_priority,
     *min_priority = layer->min_gnl_priority;
     *max_priority = layer->max_gnl_priority;
   } else {
-    *min_priority = 0;
+    *min_priority = MIN_GNL_PRIO;
     *max_priority = G_MAXUINT32;
   }
 }
@@ -356,9 +356,9 @@ _child_removed (GESContainer * container, GESTimelineElement * element)
 }
 
 static void
-add_tlobj_to_list (gpointer key, gpointer tlobj, GList ** list)
+add_clip_to_list (gpointer key, gpointer clip, GList ** list)
 {
-  *list = g_list_prepend (*list, gst_object_ref (tlobj));
+  *list = g_list_prepend (*list, gst_object_ref (clip));
 }
 
 static GList *
@@ -417,7 +417,7 @@ _ungroup (GESContainer * container, gboolean recursive)
     }
   }
   g_list_free_full (children, gst_object_unref);
-  g_hash_table_foreach (_tracktype_clip, (GHFunc) add_tlobj_to_list, &ret);
+  g_hash_table_foreach (_tracktype_clip, (GHFunc) add_clip_to_list, &ret);
   g_hash_table_unref (_tracktype_clip);
 
   return ret;
@@ -1050,16 +1050,16 @@ ges_clip_get_top_effects (GESClip * clip)
 }
 
 /**
- * ges_clip_get_top_effect_position:
+ * ges_clip_get_top_effect_index:
  * @clip: The origin #GESClip
- * @effect: The #GESBaseEffect we want to get the top position from
+ * @effect: The #GESBaseEffect we want to get the top index from
  *
- * Gets the top position of an effect.
+ * Gets the index position of an effect.
  *
- * Returns: The top position of the effect, -1 if something went wrong.
+ * Returns: The top index of the effect, -1 if something went wrong.
  */
 gint
-ges_clip_get_top_effect_position (GESClip * clip, GESBaseEffect * effect)
+ges_clip_get_top_effect_index (GESClip * clip, GESBaseEffect * effect)
 {
   guint max_prio, min_prio;
 
@@ -1072,24 +1072,39 @@ ges_clip_get_top_effect_position (GESClip * clip, GESBaseEffect * effect)
       GES_TIMELINE_ELEMENT_PRIORITY (clip);
 }
 
-/**
- * ges_clip_set_top_effect_priority:
- * @clip: The origin #GESClip
- * @effect: The #GESBaseEffect to move
- * @newpriority: the new position at which to move the @effect inside this
- * #GESClip
- *
- * This is a convenience method that lets you set the priority of a top effect.
- *
- * Returns: %TRUE if @effect was successfuly moved, %FALSE otherwise.
- */
+/* TODO 2.0 remove as it is Deprecated */
+gint
+ges_clip_get_top_effect_position (GESClip * clip, GESBaseEffect * effect)
+{
+  return ges_clip_get_top_effect_index (clip, effect);
+}
+
+/* TODO 2.0 remove as it is Deprecated */
 gboolean
 ges_clip_set_top_effect_priority (GESClip * clip,
     GESBaseEffect * effect, guint newpriority)
+{
+  return ges_clip_set_top_effect_index (clip, effect, newpriority);
+}
+
+/**
+ * ges_clip_set_top_effect_index:
+ * @clip: The origin #GESClip
+ * @effect: The #GESBaseEffect to move
+ * @newindex: the new index at which to move the @effect inside this
+ * #GESClip
+ *
+ * This is a convenience method that lets you set the index of a top effect.
+ *
+ * Returns: %TRUE if @effect was successfuly moved, %FALSE otherwise.
+ */
+gboolean
+ges_clip_set_top_effect_index (GESClip * clip, GESBaseEffect * effect,
+    guint newindex)
 {
   gint inc;
   GList *tmp;
-  guint current_prio;
+  guint current_prio, min_prio, max_prio;
   GESTrackElement *track_element;
 
   g_return_val_if_fail (GES_IS_CLIP (clip), FALSE);
@@ -1097,32 +1112,33 @@ ges_clip_set_top_effect_priority (GESClip * clip,
   track_element = GES_TRACK_ELEMENT (effect);
   current_prio = _PRIORITY (track_element);
 
-  /* FIXME, do we actually want to change what the user is telling us to do? */
-  newpriority = newpriority + MIN_GNL_PRIO;
+  _get_priority_range (GES_CONTAINER (clip), &min_prio, &max_prio);
+
+  newindex = newindex + min_prio;
   /*  We don't change the priority */
-  if (current_prio == newpriority ||
+  if (current_prio == newindex ||
       (G_UNLIKELY (GES_CLIP (GES_TIMELINE_ELEMENT_PARENT (track_element)) !=
               clip)))
     return FALSE;
 
-  if (newpriority > (clip->priv->nb_effects - 1 + MIN_GNL_PRIO)) {
+  if (newindex > (clip->priv->nb_effects - 1 + min_prio)) {
     GST_DEBUG ("You are trying to make %p not a top effect", effect);
     return FALSE;
   }
 
-  if (current_prio > clip->priv->nb_effects + MIN_GNL_PRIO) {
-    GST_DEBUG ("%p is not a top effect", effect);
+  if (current_prio > clip->priv->nb_effects + min_prio) {
+    GST_ERROR ("%p is not a top effect", effect);
     return FALSE;
   }
 
   _ges_container_sort_children (GES_CONTAINER (clip));
-  if (_PRIORITY (track_element) < newpriority)
+  if (_PRIORITY (track_element) < newindex)
     inc = -1;
   else
     inc = +1;
 
   GST_DEBUG_OBJECT (clip, "Setting top effect %" GST_PTR_FORMAT "priority: %i",
-      effect, newpriority);
+      effect, newindex);
 
   for (tmp = GES_CONTAINER_CHILDREN (clip); tmp; tmp = tmp->next) {
     GESTrackElement *tmpo = GES_TRACK_ELEMENT (tmp->data);
@@ -1131,12 +1147,12 @@ ges_clip_set_top_effect_priority (GESClip * clip,
     if (tmpo == track_element)
       continue;
 
-    if ((inc == +1 && tck_priority >= newpriority) ||
-        (inc == -1 && tck_priority <= newpriority)) {
+    if ((inc == +1 && tck_priority >= newindex) ||
+        (inc == -1 && tck_priority <= newindex)) {
       _set_priority0 (GES_TIMELINE_ELEMENT (tmpo), tck_priority + inc);
     }
   }
-  _set_priority0 (GES_TIMELINE_ELEMENT (track_element), newpriority);
+  _set_priority0 (GES_TIMELINE_ELEMENT (track_element), newindex);
 
   return TRUE;
 }
@@ -1424,4 +1440,58 @@ ges_clip_add_asset (GESClip * clip, GESAsset * asset)
     return NULL;
 
   return element;
+
+}
+
+/**
+ * ges_clip_find_track_elements:
+ * @clip: a #GESClip
+ * @track: (allow-none): a #GESTrack or NULL
+ * @track_type: a #GESTrackType indicating the type of tracks in which elements
+ * should be searched.
+ * @type: a #GType indicating the type of track element you are looking
+ * for or %G_TYPE_NONE if you do not care about the track type.
+ *
+ * Finds all the #GESTrackElement controlled by @clip that is used in @track. You
+ * may optionally specify a GType to further narrow search criteria.
+ *
+ * Returns: (transfer full) (element-type GESTrackElement): a #GList of the
+ * #GESTrackElement contained in @clip.
+ * The refcount of the objects will be increased. The user will have to
+ * unref each #GESTrackElement and free the #GList.
+ */
+
+GList *
+ges_clip_find_track_elements (GESClip * clip, GESTrack * track,
+    GESTrackType track_type, GType type)
+{
+  GList *tmp;
+  GESTrack *tmptrack;
+  GESTrackElement *otmp;
+  GESTrackElement *foundElement;
+
+  GList *ret = NULL;
+
+  g_return_val_if_fail (GES_IS_CLIP (clip), NULL);
+  g_return_val_if_fail (!(track == NULL && type == G_TYPE_NONE &&
+          track_type == GES_TRACK_TYPE_UNKNOWN), NULL);
+
+  for (tmp = GES_CONTAINER_CHILDREN (clip); tmp; tmp = g_list_next (tmp)) {
+    otmp = (GESTrackElement *) tmp->data;
+
+    if ((type != G_TYPE_NONE) && !G_TYPE_CHECK_INSTANCE_TYPE (tmp->data, type))
+      continue;
+
+    tmptrack = ges_track_element_get_track (otmp);
+    if (((track != NULL && tmptrack == track)) ||
+        (track_type != GES_TRACK_TYPE_UNKNOWN
+            && tmptrack->type == track_type)) {
+
+      foundElement = GES_TRACK_ELEMENT (tmp->data);
+
+      ret = g_list_append (ret, gst_object_ref (foundElement));
+    }
+  }
+
+  return ret;
 }
