@@ -91,6 +91,15 @@ void
 timeline_remove_group          (GESTimeline *timeline,
                                 GESGroup *group);
 
+G_GNUC_INTERNAL
+gboolean
+timeline_add_element           (GESTimeline *timeline,
+                                GESTimelineElement *element);
+G_GNUC_INTERNAL
+gboolean
+timeline_remove_element       (GESTimeline *timeline,
+                               GESTimelineElement *element);
+
 G_GNUC_INTERNAL void
 ges_asset_cache_init (void);
 
@@ -252,6 +261,8 @@ G_GNUC_INTERNAL gint element_start_compare                (GESTimelineElement *
                                                            GESTimelineElement * b);
 G_GNUC_INTERNAL gint element_end_compare                  (GESTimelineElement * a,
                                                            GESTimelineElement * b);
+G_GNUC_INTERNAL GstElementFactory *
+ges_get_compositor_factory                                (void);
 
 void
 ges_base_xml_formatter_set_timeline_properties(GESBaseXmlFormatter * self,
@@ -304,4 +315,16 @@ G_GNUC_INTERNAL GESImageSource     * ges_image_source_new      (gchar *uri);
 G_GNUC_INTERNAL GESTitleSource     * ges_title_source_new      (void);
 G_GNUC_INTERNAL GESVideoTestSource * ges_video_test_source_new (void);
 
+/******************************
+ *  GESMultiFile internal API *
+ ******************************/
+typedef struct GESMultiFileURI
+{
+  gchar *location;
+  gint start;
+  gint end;
+} GESMultiFileURI;
+
+G_GNUC_INTERNAL GESMultiFileURI * ges_multi_file_uri_new (const gchar * uri);
+
 #endif /* __GES_INTERNAL_H__ */
