@@ -1,10 +1,30 @@
+/* GStreamer Editing Services
+ * Copyright (C) 2012 Paul Lange <palango@gmx.de>
+ * Copyright (C) <2014> Thibault Saunier <thibault.saunier@collabora.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <glib-object.h>
 #include <gst/gst.h>
 
 #include "ges-meta-container.h"
 
 /**
-* SECTION: ges-meta-container
+* SECTION: gesmetacontainer
 * @short_description: An interface for storing meta
 *
 * Interface that allows reading and writing meta
@@ -211,7 +231,7 @@ _can_write_value (GESMetaContainer * container, const gchar * item_name,
 
   data = g_object_get_qdata (G_OBJECT (container), ges_meta_key);
   if (!data) {
-    data = _create_container_data (container);
+    _create_container_data (container);
     return TRUE;
   }
 
