@@ -22,7 +22,7 @@
  */
 
 /**
- * SECTION:ges-timeline
+ * SECTION:gestimeline
  * @short_description: Multimedia timeline
  *
  * #GESTimeline is the central object for any multimedia timeline.
@@ -187,6 +187,8 @@ struct _GESTimelinePrivate
   GList *groups;
 
   guint group_id;
+
+  GHashTable *all_elements;
 };
 
 /* private structure to contain our track-related information */
@@ -557,6 +559,9 @@ ges_timeline_init (GESTimeline * self)
       g_hash_table_new_full (g_str_hash, g_str_equal, NULL, gst_object_unref);
   priv->needs_transitions_update = TRUE;
 
+  priv->all_elements =
+      g_hash_table_new_full (g_str_hash, g_str_equal, g_free, gst_object_unref);
+
   priv->group_id = -1;
 
   g_signal_connect_after (self, "select-tracks-for-object",
@@ -877,7 +882,7 @@ _create_transitions_on_layer (GESTimeline * timeline, GESLayer * layer,
             get_auto_transition (timeline, layer, ctrack, prev, next,
             transition_duration);
         if (!transition)
-          transition = create_transition (timeline, prev, next, NULL, layer,
+          create_transition (timeline, prev, next, NULL, layer,
               _START (next), transition_duration);
       }
     }
@@ -1403,8 +1408,7 @@ ges_timeline_trim_object_simple (GESTimeline * timeline,
 
       /* Calculate new values */
       position = MIN (position, start + duration);
-      inpoint =
-          MAX (0, inpoint + position > start ? inpoint + position - start : 0);
+      inpoint = inpoint + position > start ? inpoint + position - start : 0;
 
       real_dur = _END (element) - position;
       /* FIXME: Why CLAMP (0, real_dur, max_duration) doesn't work? */
@@ -2202,7 +2206,8 @@ trackelement_priority_changed_cb (GESTrackElement * child,
     GST_ERROR_OBJECT (timeline,
         "Changing a TrackElement prio, which would not "
         "land in no layer we are controlling");
-    g_sequence_remove (iters->iter_by_layer);
+    if (iters->iter_by_layer)
+      g_sequence_remove (iters->iter_by_layer);
     iters->iter_by_layer = NULL;
     iters->layer = NULL;
   } else {
@@ -2387,6 +2392,32 @@ pad_removed_cb (GESTrack * track, GstPad * pad, TrackPrivate * tr_priv)
   tr_priv->pad = NULL;
 }
 
+gboolean
+timeline_add_element (GESTimeline * timeline, GESTimelineElement * element)
+{
+  GESTimelineElement *same_name =
+      g_hash_table_lookup (timeline->priv->all_elements,
+      element->name);
+
+  GST_DEBUG_OBJECT (timeline, "Adding element: %s", element->name);
+  if (same_name) {
+    GST_ERROR_OBJECT (timeline, "%s Already in the timeline %" GST_PTR_FORMAT,
+        element->name, same_name);
+    return FALSE;
+  }
+
+  g_hash_table_insert (timeline->priv->all_elements,
+      ges_timeline_element_get_name (element), gst_object_ref (element));
+
+  return TRUE;
+}
+
+gboolean
+timeline_remove_element (GESTimeline * timeline, GESTimelineElement * element)
+{
+  return g_hash_table_remove (timeline->priv->all_elements, element->name);
+}
+
 /**** API *****/
 /**
  * ges_timeline_new:
@@ -3027,3 +3058,27 @@ ges_timeline_set_snapping_distance (GESTimeline * timeline,
 
   timeline->priv->snapping_distance = snapping_distance;
 }
+
+/**
+ * ges_timeline_get_element:
+ * @timeline: a #GESTimeline
+ *
+ * Gets a #GESTimelineElement contained in the timeline
+ *
+ * Returns: (transfer full): The #GESTimelineElement or %NULL if
+ * not found.
+ */
+GESTimelineElement *
+ges_timeline_get_element (GESTimeline * timeline, const gchar * name)
+{
+  GESTimelineElement *ret;
+
+  g_return_val_if_fail (GES_IS_TIMELINE (timeline), NULL);
+
+  ret = g_hash_table_lookup (timeline->priv->all_elements, name);
+
+  if (ret)
+    return gst_object_ref (ret);
+
+  return NULL;
+}
