@@ -326,6 +326,9 @@ _parse_track (GMarkupParseContext * context, const gchar * element_name,
   ges_base_xml_formatter_add_track (GES_BASE_XML_FORMATTER (self), track_type,
       caps, strtrack_id, props, metadatas, error);
 
+  if (props)
+    gst_structure_free (props);
+
   return;
 
 wrong_caps:
@@ -388,12 +391,15 @@ _parse_layer (GMarkupParseContext * context, const gchar * element_name,
       goto wrong_properties;
   }
 
+  errno = 0;
   priority = g_ascii_strtoll (strprio, NULL, 10);
   if (errno)
     goto convertion_failed;
 
   ges_base_xml_formatter_add_layer (GES_BASE_XML_FORMATTER (self),
       extractable_type, priority, props, metadatas, error);
+
+done:
   if (props)
     gst_structure_free (props);
 
@@ -404,7 +410,7 @@ convertion_failed:
       G_MARKUP_ERROR_INVALID_CONTENT,
       "element '%s', Wrong property type, error: %s'", element_name,
       g_strerror (errno));
-  return;
+  goto done;
 
 wrong_properties:
   g_set_error (error, G_MARKUP_ERROR,
@@ -446,6 +452,7 @@ _parse_clip (GMarkupParseContext * context,
   if (!g_type_is_a (type, GES_TYPE_CLIP))
     goto wrong_type;
 
+  errno = 0;
   track_types = g_ascii_strtoll (strtrack_types, NULL, 10);
   if (errno)
     goto convertion_failed;
@@ -598,6 +605,8 @@ _parse_effect (GMarkupParseContext * context, const gchar * element_name,
       type, asset_id, track_id, clip_id, children_props, props, metadatas,
       error);
 
+out:
+
   if (props)
     gst_structure_free (props);
   if (children_props)
@@ -610,14 +619,14 @@ wrong_properties:
       G_MARKUP_ERROR_INVALID_CONTENT,
       "element '%s', Effect %s properties '%s', could no be deserialized",
       element_name, asset_id, properties);
-  return;
+  goto out;
 
 wrong_children_properties:
   g_set_error (error, G_MARKUP_ERROR,
       G_MARKUP_ERROR_INVALID_CONTENT,
       "element '%s', Effect %s children properties '%s', could no be deserialized",
       element_name, asset_id, children_properties);
-  return;
+  goto out;
 
 wrong_type:
   g_set_error (error, G_MARKUP_ERROR,
@@ -702,7 +711,8 @@ _can_serialize_spec (GParamSpec * spec)
 {
   if (spec->flags & G_PARAM_WRITABLE && !(spec->flags & G_PARAM_CONSTRUCT_ONLY)
       && !g_type_is_a (G_PARAM_SPEC_VALUE_TYPE (spec), G_TYPE_OBJECT)
-      && g_strcmp0 (spec->name, "name")
+      && (!(g_type_is_a (spec->owner_type, GST_TYPE_OBJECT) &&
+              !g_strcmp0 (spec->name, "name")))
       && G_PARAM_SPEC_VALUE_TYPE (spec) != G_TYPE_GTYPE)
     return TRUE;
 
