@@ -90,7 +90,7 @@ GST_START_TEST (test_ges_scenario)
   tmp_layer = ges_clip_get_layer (GES_CLIP (source));
   fail_unless (tmp_layer == layer);
   /* The timeline stole our reference */
-  ASSERT_OBJECT_REFCOUNT (source, "source", 1);
+  ASSERT_OBJECT_REFCOUNT (source, "source + 1 timeline", 2);
   gst_object_unref (tmp_layer);
   ASSERT_OBJECT_REFCOUNT (layer, "layer", 1);
 
@@ -101,13 +101,13 @@ GST_START_TEST (test_ges_scenario)
   /* There are 3 references:
    * 1 by the clip
    * 1 by the track
-   * 1 by the timeline */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 3);
+   * 2 by the timeline */
+  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 4);
   /* There are 3 references:
    * 1 by the clip
-   * 1 by the timeline
+   * 2 by the timeline
    * 1 by the track */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 3);
+  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 4);
 
   GST_DEBUG ("Remove the Clip from the layer");
 
@@ -232,13 +232,13 @@ GST_START_TEST (test_ges_timeline_add_layer)
   /* There are 3 references:
    * 1 by the clip
    * 1 by the trackelement
-   * 1 by the timeline */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 3);
+   * 2 by the timeline */
+  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 4);
   /* There are 3 references:
    * 1 by the clip
    * 1 by the timeline
-   * 1 by the trackelement */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 3);
+   * 2 by the trackelement */
+  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 4);
 
   trackelements = GES_CONTAINER_CHILDREN (s2);
   trackelement = GES_TRACK_ELEMENT (trackelements->data);
@@ -247,8 +247,8 @@ GST_START_TEST (test_ges_timeline_add_layer)
   /* There are 3 references:
    * 1 by the clip
    * 1 by the timeline
-   * 1 by the trackelement */
-  ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (trackelement), "trackelement", 3);
+   * 2 by the trackelement */
+  ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (trackelement), "trackelement", 4);
 
   trackelements = GES_CONTAINER_CHILDREN (s3);
   trackelement = GES_TRACK_ELEMENT (trackelements->data);
@@ -257,8 +257,8 @@ GST_START_TEST (test_ges_timeline_add_layer)
   /* There are 3 references:
    * 1 by the clip
    * 1 by the timeline
-   * 1 by the trackelement */
-  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 3);
+   * 2 by the trackelement */
+  ASSERT_OBJECT_REFCOUNT (trackelement, "trackelement", 4);
 
   /* theoretically this is all we need to do to ensure cleanup */
   gst_object_unref (timeline);
@@ -339,8 +339,8 @@ GST_START_TEST (test_ges_timeline_add_layer_first)
     /* Each object has 3 references:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
   }
 
   trackelements = GES_CONTAINER_CHILDREN (s2);
@@ -349,8 +349,8 @@ GST_START_TEST (test_ges_timeline_add_layer_first)
     /* Each object has 3 references:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
   }
 
   trackelements = GES_CONTAINER_CHILDREN (s3);
@@ -359,8 +359,8 @@ GST_START_TEST (test_ges_timeline_add_layer_first)
     /* Each object has 3 references:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
   }
 
   /* theoretically this is all we need to do to ensure cleanup */
@@ -447,14 +447,14 @@ GST_START_TEST (test_ges_timeline_remove_track)
     /* There are 3 references held:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
   }
   /* There are 3 references held:
    * 1 by the container
    * 1 by the track
-   * 1 by the timeline */
-  ASSERT_OBJECT_REFCOUNT (t1, "trackelement", 3);
+   * 2 by the timeline */
+  ASSERT_OBJECT_REFCOUNT (t1, "trackelement", 4);
 
   trackelements = GES_CONTAINER_CHILDREN (s2);
   fail_unless (trackelements != NULL);
@@ -463,14 +463,14 @@ GST_START_TEST (test_ges_timeline_remove_track)
     /* There are 3 references held:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
   }
   /* There are 3 references held:
    * 1 by the container
    * 1 by the track
-   * 1 by the timeline */
-  ASSERT_OBJECT_REFCOUNT (t2, "t2", 3);
+   * 2 by the timeline */
+  ASSERT_OBJECT_REFCOUNT (t2, "t2", 4);
 
   trackelements = GES_CONTAINER_CHILDREN (s3);
   fail_unless (trackelements != NULL);
@@ -479,14 +479,14 @@ GST_START_TEST (test_ges_timeline_remove_track)
     /* There are 3 references held:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
   }
   /* There are 3 references held:
    * 1 by the container
    * 1 by the track
-   * 1 by the timeline */
-  ASSERT_OBJECT_REFCOUNT (t3, "t3", 3);
+   * 2 by the timeline */
+  ASSERT_OBJECT_REFCOUNT (t3, "t3", 4);
 
   /* remove the track and check that the track elements have been released */
   fail_unless (ges_timeline_remove_track (timeline, track));
@@ -613,17 +613,17 @@ GST_START_TEST (test_ges_timeline_multiple_tracks)
     /* There are 3 references held:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
     fail_unless (ges_track_element_get_track (tmp->data) == track1);
   }
   gst_object_ref (t1);
   /* There are 3 references held:
    * 1 by the container
    * 1 by the track
-   * 1 by the timeline
+   * 2 by the timeline
    * 1 added by ourselves above (gst_object_ref (t1)) */
-  ASSERT_OBJECT_REFCOUNT (t1, "trackelement", 4);
+  ASSERT_OBJECT_REFCOUNT (t1, "trackelement", 5);
 
   trackelements = GES_CONTAINER_CHILDREN (s2);
   fail_unless (trackelements != NULL);
@@ -632,17 +632,17 @@ GST_START_TEST (test_ges_timeline_multiple_tracks)
     /* There are 3 references held:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
     fail_unless (ges_track_element_get_track (tmp->data) == track2);
   }
   gst_object_ref (t2);
   /* There are 3 references held:
    * 1 by the container
    * 1 by the track
-   * 1 by the timeline
+   * 2 by the timeline
    * 1 added by ourselves above (gst_object_ref (t2)) */
-  ASSERT_OBJECT_REFCOUNT (t2, "t2", 4);
+  ASSERT_OBJECT_REFCOUNT (t2, "t2", 5);
 
   trackelements = GES_CONTAINER_CHILDREN (s3);
   fail_unless (trackelements != NULL);
@@ -651,17 +651,17 @@ GST_START_TEST (test_ges_timeline_multiple_tracks)
     /* There are 3 references held:
      * 1 by the clip
      * 1 by the track
-     * 1 by the timeline */
-    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 3);
+     * 2 by the timeline */
+    ASSERT_OBJECT_REFCOUNT (GES_TRACK_ELEMENT (tmp->data), "trackelement", 4);
     fail_unless (ges_track_element_get_track (tmp->data) == track1);
   }
   gst_object_ref (t3);
   /* There are 3 references held:
    * 1 by the container
    * 1 by the track
-   * 1 by the timeline
+   * 2 by the timeline
    * 1 added by ourselves above (gst_object_ref (t3)) */
-  ASSERT_OBJECT_REFCOUNT (t3, "t3", 4);
+  ASSERT_OBJECT_REFCOUNT (t3, "t3", 5);
 
   gst_object_unref (t1);
   gst_object_unref (t2);
@@ -706,6 +706,70 @@ GST_START_TEST (test_ges_pipeline_change_state)
 
 GST_END_TEST;
 
+GST_START_TEST (test_ges_timeline_element_name)
+{
+  GESClip *clip, *clip1, *clip2, *clip3, *clip4, *clip5;
+  GESAsset *asset;
+  GESTimeline *timeline;
+  GESLayer *layer;
+
+  ges_init ();
+
+  timeline = ges_timeline_new_audio_video ();
+  layer = ges_layer_new ();
+  fail_unless (ges_timeline_add_layer (timeline, layer));
+
+  asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
+  clip = ges_layer_add_asset (layer, asset, 0, 0, 10, GES_TRACK_TYPE_UNKNOWN);
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip), "testclip0");
+
+
+  clip1 = GES_CLIP (ges_test_clip_new ());
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip1), "testclip1");
+
+  ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (clip1), "testclip1");
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip1), "testclip1");
+
+  /* Check that trying to set to a name that is already used leads to
+   * a change in the name */
+  ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (clip), "testclip1");
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip), "testclip2");
+
+  ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (clip1), "testclip4");
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip1), "testclip4");
+
+  clip2 = GES_CLIP (ges_test_clip_new ());
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip2), "testclip5");
+  ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (clip2), NULL);
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip2), "testclip6");
+
+  clip3 = GES_CLIP (ges_test_clip_new ());
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip3), "testclip7");
+  ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (clip3), "testclip5");
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip3), "testclip8");
+
+  clip4 = GES_CLIP (ges_test_clip_new ());
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip4), "testclip9");
+
+
+  clip5 = GES_CLIP (ges_test_clip_new ());
+  ges_timeline_element_set_name (GES_TIMELINE_ELEMENT (clip5),
+      "Something I want!");
+  fail_unless_equals_string (GES_TIMELINE_ELEMENT_NAME (clip5),
+      "Something I want!");
+
+  gst_object_unref (asset);
+
+  gst_object_unref (clip1);
+  gst_object_unref (clip2);
+  gst_object_unref (clip3);
+  gst_object_unref (clip4);
+  gst_object_unref (clip5);
+  gst_object_unref (timeline);
+}
+
+GST_END_TEST;
+
 static Suite *
 ges_suite (void)
 {
@@ -721,6 +785,7 @@ ges_suite (void)
   tcase_add_test (tc_chain, test_ges_timeline_remove_track);
   tcase_add_test (tc_chain, test_ges_timeline_multiple_tracks);
   tcase_add_test (tc_chain, test_ges_pipeline_change_state);
+  tcase_add_test (tc_chain, test_ges_timeline_element_name);
 
   return s;
 }
