@@ -30,16 +30,21 @@
 #include <gst/pbutils/encoding-profile.h>
 
 #include <locale.h>             /* for LC_ALL */
+#include "ges-validate.h"
 
 /* GLOBAL VARIABLE */
 static guint repeat = 0;
+static gboolean mute = FALSE;
+static gboolean disable_mixing = FALSE;
 static GESPipeline *pipeline = NULL;
 static gboolean seenerrors = FALSE;
 static gchar *save_path = NULL;
-static gchar **new_paths = NULL;
+static GPtrArray *new_paths = NULL;
 static GMainLoop *mainloop;
 static GHashTable *tried_uris;
 static GESTrackType track_types = GES_TRACK_TYPE_AUDIO | GES_TRACK_TYPE_VIDEO;
+static GESTimeline *timeline;
+static gboolean needs_set_state;
 
 static gchar *
 ensure_uri (gchar * location)
@@ -67,6 +72,58 @@ get_flags_from_string (GType type, const gchar * str_flags)
   return flags;
 }
 
+
+static void
+_add_media_new_paths_recursing (const gchar * value)
+{
+  GFileInfo *info;
+  GFileEnumerator *fenum;
+  GFile *file = g_file_new_for_uri (value);
+
+  if (!(fenum = g_file_enumerate_children (file,
+              "standard::*", G_FILE_QUERY_INFO_NONE, NULL, NULL))) {
+    GST_INFO ("%s is not a folder", value);
+
+    goto done;
+  }
+
+  GST_INFO ("Adding folder: %s", value);
+  g_ptr_array_add (new_paths, g_strdup (value));
+  for (info = g_file_enumerator_next_file (fenum, NULL, NULL);
+      info; info = g_file_enumerator_next_file (fenum, NULL, NULL)) {
+
+    if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY) {
+      GFile *f = g_file_enumerator_get_child (fenum, info);
+      gchar *uri = g_file_get_uri (f);
+
+      _add_media_new_paths_recursing (uri);
+      gst_object_unref (f);
+      g_free (uri);
+    }
+  }
+
+done:
+  gst_object_unref (file);
+  if (fenum)
+    gst_object_unref (fenum);
+}
+
+static gboolean
+_add_media_path (const gchar * option_name, const gchar * value,
+    gpointer udata, GError ** error)
+{
+  g_return_val_if_fail (gst_uri_is_valid (value), FALSE);
+
+  if (g_strcmp0 (option_name, "--sample-path-recurse") == 0) {
+    _add_media_new_paths_recursing (value);
+  } else {
+    GST_INFO ("Adding folder: %s", value);
+    g_ptr_array_add (new_paths, g_strdup (value));
+  }
+
+  return TRUE;
+}
+
 static gboolean
 parse_track_type (const gchar * option_name, const gchar * value,
     gpointer udata, GError ** error)
@@ -103,11 +160,11 @@ source_moved_cb (GESProject * project, GError * error, GESAsset * asset)
   gint i;
   const gchar *old_uri = ges_asset_get_id (asset);
 
-  for (i = 0; new_paths[i] != NULL; i++) {
+  for (i = 0; i < new_paths->len; i++) {
     gchar *basename, *res;
 
     basename = g_path_get_basename (old_uri);
-    res = g_build_filename (new_paths[i], basename, NULL);
+    res = g_build_filename (new_paths->pdata[i], basename, NULL);
     g_free (basename);
 
     if (g_hash_table_lookup (tried_uris, res)) {
@@ -161,7 +218,7 @@ project_loaded_cb (GESProject * project, GESTimeline * timeline)
     }
   }
 
-  if (gst_element_set_state (GST_ELEMENT (pipeline),
+  if (needs_set_state && gst_element_set_state (GST_ELEMENT (pipeline),
           GST_STATE_PLAYING) == GST_STATE_CHANGE_FAILURE) {
     g_error ("Failed to start the pipeline\n");
   }
@@ -186,23 +243,34 @@ check_time (char *time)
 static guint64
 str_to_time (char *time)
 {
-  if (check_time (time)) {
-    return (guint64) (atof (time) * GST_SECOND);
-  }
-  GST_ERROR ("%s not a valid time", time);
-  return 0;
+  gdouble nsecs;
+
+  g_return_val_if_fail (check_time (time), 0);
+
+  nsecs = g_ascii_strtod (time, NULL);
+
+  return nsecs * GST_SECOND;
+}
+
+static void
+_clip_added_cb (GESLayer * layer, GESClip * clip, GESAsset * asset)
+{
+  if (GES_IS_TRANSITION_CLIP (clip))
+    ges_extractable_set_asset (GES_EXTRACTABLE (clip), asset);
 }
 
 static GESTimeline *
-create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
+create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri,
+    const gchar * scenario)
 {
-  GESLayer *layer;
+  GESLayer *layer = NULL;
   GESTrack *tracka = NULL, *trackv = NULL;
   GESTimeline *timeline;
-  guint i;
+  guint i, clip_added_sigid = 0;
+  GstClockTime next_trans_dur = 0;
   GESProject *project = ges_project_new (proj_uri);
 
-  if (new_paths)
+  if (new_paths->len)
     g_signal_connect (project, "missing-uri",
         G_CALLBACK (source_moved_cb), NULL);
 
@@ -215,18 +283,16 @@ create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
 
   timeline = GES_TIMELINE (ges_asset_extract (GES_ASSET (project), NULL));
 
-  if (proj_uri)
-    return timeline;
-
-  /* We are only going to be doing one layer of clips */
-  layer = (GESLayer *) ges_layer_new ();
-
-  /* Add the tracks and the layer to the timeline */
-  if (!ges_timeline_add_layer (timeline, layer))
-    goto build_failure;
+  if (proj_uri) {
+    goto done;
+  }
 
+  g_object_set (timeline, "auto-transition", TRUE, NULL);
   if (track_types & GES_TRACK_TYPE_AUDIO) {
     tracka = GES_TRACK (ges_audio_track_new ());
+    if (disable_mixing)
+      ges_track_set_mixing (tracka, FALSE);
+
     if (!(ges_timeline_add_track (timeline, tracka)))
       goto build_failure;
   }
@@ -234,6 +300,9 @@ create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
   if (track_types & GES_TRACK_TYPE_VIDEO) {
     trackv = GES_TRACK (ges_video_track_new ());
 
+    if (disable_mixing)
+      ges_track_set_mixing (trackv, FALSE);
+
     if (!(ges_timeline_add_track (timeline, trackv)))
       goto build_failure;
   }
@@ -248,6 +317,18 @@ create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
     char *arg0 = argv[(i * 3) + 1];
     guint64 duration = str_to_time (argv[(i * 3) + 2]);
 
+    if (i == 0) {
+      /* We are only going to be doing one layer of clips */
+      layer = (GESLayer *) ges_layer_new ();
+
+      /* Add the tracks and the layer to the timeline */
+      if (!ges_timeline_add_layer (timeline, layer))
+        goto build_failure;
+    }
+
+    if (duration == 0)
+      duration = GST_CLOCK_TIME_NONE;
+
     if (!g_strcmp0 ("+pattern", source)) {
       clip = GES_CLIP (ges_test_clip_new_for_nick (arg0));
       if (!clip) {
@@ -262,26 +343,19 @@ create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
     }
 
     else if (!g_strcmp0 ("+transition", source)) {
-      if (duration <= 0) {
-        g_error ("durations must be greater than 0");
-        goto build_failure;
+      GESAsset *asset =
+          ges_asset_request (GES_TYPE_TRANSITION_CLIP, arg0, NULL);
+
+      if (asset == NULL) {
+        g_warning ("Can not create transition %s", arg0);
       }
 
-      clip = GES_CLIP (ges_transition_clip_new_for_nick (arg0));
+      next_trans_dur = duration;
+      clip_added_sigid = g_signal_connect (layer, "clip-added",
+          (GCallback) _clip_added_cb, asset);
 
-      if (!clip) {
-        g_error ("invalid transition type\n");
-        goto build_failure;
-      }
-
-      g_object_set (G_OBJECT (clip), "duration", duration, NULL);
-
-      g_printf ("Adding <transition:%s> duration %" GST_TIME_FORMAT "\n", arg0,
-          GST_TIME_ARGS (duration));
-
-    }
-
-    else if (!g_strcmp0 ("+title", source)) {
+      continue;
+    } else if (!g_strcmp0 ("+title", source)) {
       clip = GES_CLIP (ges_title_clip_new ());
 
       g_object_set (clip, "duration", duration, "text", arg0, NULL);
@@ -318,6 +392,10 @@ create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
         return NULL;
       }
 
+      if (!GST_CLOCK_TIME_IS_VALID (duration))
+        duration =
+            GES_TIMELINE_ELEMENT_DURATION (clip) - (GstClockTime) inpoint;
+
       g_object_set (clip,
           "in-point", (guint64) inpoint, "duration", (guint64) duration, NULL);
 
@@ -328,11 +406,20 @@ create_timeline (int nbargs, gchar ** argv, const gchar * proj_uri)
       g_free (uri);
     }
 
-    g_object_set (G_OBJECT (clip), "start", ges_layer_get_duration (layer),
-        NULL);
+    g_object_set (G_OBJECT (clip), "start",
+        ges_layer_get_duration (layer) - next_trans_dur, NULL);
+
     ges_layer_add_clip (layer, clip);
+
+    if (clip_added_sigid) {
+      g_signal_handler_disconnect (layer, clip_added_sigid);
+      clip_added_sigid = 0;
+      next_trans_dur = 0;
+    }
+
   }
 
+done:
   return timeline;
 
 build_failure:
@@ -344,10 +431,9 @@ build_failure:
 
 static GESPipeline *
 create_pipeline (GESTimeline ** ret_timeline, gchar * load_path,
-    int argc, char **argv)
+    int argc, char **argv, const gchar * scenario)
 {
   gchar *uri = NULL;
-  GESPipeline *pipeline = NULL;
   GESTimeline *timeline = NULL;
 
   /* Timeline creation */
@@ -359,14 +445,14 @@ create_pipeline (GESTimeline ** ret_timeline, gchar * load_path,
       goto failure;
     }
   }
-  if (!(timeline = create_timeline (argc, argv, uri)))
+
+  pipeline = ges_pipeline_new ();
+
+  if (!(timeline = create_timeline (argc, argv, uri, scenario)))
     goto failure;
 
   ges_timeline_commit (timeline);
 
-  if (uri)
-    g_free (uri);
-
   /* save project if path is given. we do this now in case GES crashes or
    * hangs during playback. */
   if (save_path && !load_path) {
@@ -376,29 +462,44 @@ create_pipeline (GESTimeline ** ret_timeline, gchar * load_path,
       goto failure;
     }
     ges_timeline_save_to_uri (timeline, uri, NULL, TRUE, NULL);
-    g_free (uri);
   }
 
   /* In order to view our timeline, let's grab a convenience pipeline to put
    * our timeline in. */
-  pipeline = ges_pipeline_new ();
+
+  if (mute) {
+    GstElement *sink = gst_element_factory_make ("fakesink", NULL);
+
+    g_object_set (sink, "sync", TRUE, NULL);
+    ges_pipeline_preview_set_audio_sink (pipeline, sink);
+
+    sink = gst_element_factory_make ("fakesink", NULL);
+    g_object_set (sink, "sync", TRUE, NULL);
+    ges_pipeline_preview_set_video_sink (pipeline, sink);
+  }
 
   /* Add the timeline to that pipeline */
   if (!ges_pipeline_set_timeline (pipeline, timeline))
     goto failure;
 
   *ret_timeline = timeline;
+
+done:
+  if (uri)
+    g_free (uri);
+
   return pipeline;
 
 failure:
   {
-    if (uri)
-      g_free (uri);
     if (timeline)
       gst_object_unref (timeline);
     if (pipeline)
       gst_object_unref (pipeline);
-    return NULL;
+    pipeline = NULL;
+    timeline = NULL;
+
+    goto done;
   }
 }
 
@@ -439,7 +540,7 @@ bus_message_cb (GstBus * bus, GstMessage * message, GMainLoop * mainloop)
         g_printerr ("Looping set\n");
         repeat -= 1;
       } else {
-        g_printerr ("Done\n");
+        g_printerr ("\nDone\n");
         g_main_loop_quit (mainloop);
       }
       break;
@@ -462,6 +563,9 @@ bus_message_cb (GstBus * bus, GstMessage * message, GMainLoop * mainloop)
         g_free (state_transition_name);
       }
       break;
+    case GST_MESSAGE_REQUEST_STATE:
+      ges_validate_handle_request_state_change (message, mainloop);
+      break;
     default:
       break;
   }
@@ -473,8 +577,6 @@ print_enum (GType enum_type)
   GEnumClass *enum_class = G_ENUM_CLASS (g_type_class_ref (enum_type));
   guint i;
 
-  GST_ERROR ("%d", enum_class->n_values);
-
   for (i = 0; i < enum_class->n_values; i++) {
     g_printf ("%s\n", enum_class->values[i].value_nick);
   }
@@ -494,53 +596,38 @@ print_pattern_list (void)
   print_enum (GES_VIDEO_TEST_PATTERN_TYPE);
 }
 
-static gboolean
-_print_position (void)
-{
-  gint64 position, duration;
-
-  if (pipeline) {
-    gst_element_query_position (GST_ELEMENT (pipeline), GST_FORMAT_TIME,
-        &position);
-    gst_element_query_duration (GST_ELEMENT (pipeline), GST_FORMAT_TIME,
-        &duration);
-
-    g_print ("<position: %" GST_TIME_FORMAT " duration: %" GST_TIME_FORMAT
-        "/>\r", GST_TIME_ARGS (position), GST_TIME_ARGS (duration));
-  }
-
-  return TRUE;
-}
-
 static GstEncodingProfile *
 _parse_encoding_profile (const gchar * format)
 {
   GstCaps *caps;
-  char *preset_name = NULL;
-  GstEncodingProfile *encoding_profile;
+  GstEncodingProfile *encoding_profile = NULL;
   gchar **restriction_format, **preset_v;
 
-  guint i, presence = 0;
+  guint i = 1, presence = 0;
   GstCaps *restrictioncaps = NULL;
   gchar **strpresence_v, **strcaps_v = g_strsplit (format, ":", 0);
 
   if (strcaps_v[0] && *strcaps_v[0]) {
-    caps = gst_caps_from_string (strcaps_v[0]);
-    if (caps == NULL) {
-      g_printerr ("Could not parse caps %s", strcaps_v[0]);
-      return FALSE;
+    if (strcaps_v[1] == NULL) {
+      /* Only 1 profile which means no container used */
+      i = 0;
+    } else {
+      caps = gst_caps_from_string (strcaps_v[0]);
+      if (caps == NULL) {
+        g_printerr ("Could not parse caps %s", strcaps_v[0]);
+        return FALSE;
+      }
+      encoding_profile =
+          GST_ENCODING_PROFILE (gst_encoding_container_profile_new
+          ("User profile", "User profile", caps, NULL));
+      gst_caps_unref (caps);
     }
-    encoding_profile =
-        GST_ENCODING_PROFILE (gst_encoding_container_profile_new
-        ("User profile", "User profile", caps, NULL));
-    gst_caps_unref (caps);
-  } else {
-    encoding_profile = NULL;
   }
 
-  for (i = 1; strcaps_v[i]; i++) {
-    GstEncodingProfile *profile = NULL;
+  for (; strcaps_v[i]; i++) {
     gchar *strcaps, *strpresence;
+    char *preset_name = NULL;
+    GstEncodingProfile *profile = NULL;
 
     restriction_format = g_strsplit (strcaps_v[i], "->", 0);
     if (restriction_format[1]) {
@@ -651,24 +738,25 @@ main (int argc, gchar ** argv)
   static gdouble thumbinterval = 0;
   static gboolean verbose = FALSE;
   gchar *load_path = NULL;
+  gchar *videosink = NULL, *audiosink = NULL;
+  const gchar *scenario = NULL;
+  gboolean inspect_action_type = FALSE;
+  gchar *encoding_profile = NULL;
+
   GOptionEntry options[] = {
     {"thumbnail", 'm', 0.0, G_OPTION_ARG_DOUBLE, &thumbinterval,
-        "Take thumbnails every n seconds (saved in current directory)", "N"},
+        "Save thumbnail every <n> seconds to current directory", "<n>"},
     {"smartrender", 's', 0, G_OPTION_ARG_NONE, &smartrender,
-        "Render to outputuri, and avoid decoding/reencoding", NULL},
+        "Render to outputuri and avoid decoding/reencoding", NULL},
     {"outputuri", 'o', 0, G_OPTION_ARG_STRING, &outputuri,
-        "URI to encode to", "URI (<protocol>://<location>)"},
+        "URI to encode to", "<protocol>://<location>"},
     {"format", 'f', 0, G_OPTION_ARG_STRING, &format,
-          "Set the properties to use for the encoding profile "
-          "(in case of transcoding.) For example:\n"
-          "video/mpegts:video/x-raw,width=1920,height=1080->video/x-h264:audio/x-ac3\n"
-          "A preset name can be used by adding +presetname, eg:\n"
-          "video/webm:video/x-vp8+mypreset:audio/x-vorbis\n"
-          "The presence property of the profile can be specified with |<presence>, eg:\n"
-          "video/webm:video/x-vp8|<presence>:audio/x-vorbis\n",
-        "properties-values"},
+          "Specify an encoding profile on the command line",
+        "<profile>"},
+    {"encoding-profile", 'e', 0, G_OPTION_ARG_STRING, &encoding_profile,
+        "Use a specific encoding profile from XML", "<profile-name>"},
     {"repeat", 'r', 0, G_OPTION_ARG_INT, &repeat,
-        "Number of time to repeat timeline", NULL},
+        "Number of times to repeat timeline", "<times>"},
     {"list-transitions", 't', 0, G_OPTION_ARG_NONE, &list_transitions,
         "List valid transition types and exit", NULL},
     {"list-patterns", 'p', 0, G_OPTION_ARG_NONE, &list_patterns,
@@ -680,23 +768,45 @@ main (int argc, gchar ** argv)
     {"verbose", 0, 0, G_OPTION_ARG_NONE, &verbose,
         "Output status information and property notifications", NULL},
     {"exclude", 'X', 0, G_OPTION_ARG_NONE, &exclude_args,
-        "Do not output status information of TYPE", "TYPE1,TYPE2,..."},
-    {"sample-paths", 'P', 0, G_OPTION_ARG_STRING_ARRAY, &new_paths,
+        "Do not output status information of <type>", "<type1>,<type2>,..."},
+    {"sample-paths", 'P', 0, G_OPTION_ARG_CALLBACK, &_add_media_path,
         "List of pathes to look assets in if they were moved"},
-    {"track-types", 'P', 0, G_OPTION_ARG_CALLBACK, &parse_track_type,
+    {"sample-path-recurse", 'R', 0, G_OPTION_ARG_CALLBACK,
+          &_add_media_path,
+        "Same as above, but recursing into the folder"},
+    {"track-types", 'p', 0, G_OPTION_ARG_CALLBACK, &parse_track_type,
         "Defines the track types to be created"},
+    {"mute", 0, 0, G_OPTION_ARG_NONE, &mute,
+        "Mute playback output by using fakesinks"},
+    {"disable-mixing", 0, 0, G_OPTION_ARG_NONE, &disable_mixing,
+        "Do not use mixing element in the tracks"},
+    {"videosink", 'v', 0, G_OPTION_ARG_STRING, &videosink,
+        "The video sink used for playing back", "<videosink>"},
+    {"audiosink", 'a', 0, G_OPTION_ARG_STRING, &audiosink,
+        "The audio sink used for playing back", "<audiosink>"},
+#ifdef HAVE_GST_VALIDATE
+    {"inspect-action-type", 'y', 0, G_OPTION_ARG_NONE, &inspect_action_type,
+          "Inspect the avalaible action types with which to write scenarios"
+          " if no parameter passed, it will list all avalaible action types"
+          " otherwize will print the full description of the wanted types",
+        NULL},
+    {"set-scenario", 0, 0, G_OPTION_ARG_STRING, &scenario,
+        "Specify a GstValidate scenario to run, 'none' means load gst-validate"
+          " but run no scenario on it", "<scenario_name>"},
+#endif
     {NULL}
   };
+
   GOptionContext *ctx;
   GstBus *bus;
-  GESTimeline *timeline;
 
   setlocale (LC_ALL, "");
 
+  new_paths = g_ptr_array_new_with_free_func (g_free);
   ctx = g_option_context_new ("- plays or renders a timeline.");
   g_option_context_set_summary (ctx,
       "ges-launch renders a timeline, which can be specified on the commandline,\n"
-      "or loaded from a file using the -q option.\n\n"
+      "or loaded from a xges file using the -l option.\n\n"
       "A timeline is a list of files, patterns, and transitions to be rendered\n"
       "one after the other. Files and Patterns provide video and audio as the\n"
       "primary input, and transitions animate between the end of one file/pattern\n"
@@ -708,8 +818,27 @@ main (int argc, gchar ** argv)
       "or \"+transition\", followed by a <type> and duration (in seconds, must be\n"
       "greater than 0)\n\n"
       "Durations in all cases can be fractions of a second.\n\n"
-      "Example:\n"
-      "ges-launch file1.avi 0 45 +transition crossfade 3.5 file2.avi 0 0");
+      "========\nExamples\n========\n\n"
+      "Play video1.ogv from inpoint 5 with duration 10 in seconds:\n"
+      "$ ges-launch video1.ogv 5 10\n\n"
+      "Crossfade:\n"
+      "$ ges-launch video1.ogv 0 10 +transition crossfade 3.5 video2.ogv 0 10\n\n"
+      "Render xges to ogv:\n"
+      "$ ges-launch -l project.xges -o rendering.ogv\n\n"
+      "Render xges to an XML encoding-profile called mymkv:\n"
+      "$ ges-launch -l project.xges -o rendering.mkv -e mymkv\n\n"
+      "Render to mp4:\n"
+      "$ ges-launch -l project.xges -o out.mp4 \\\n"
+      "             -f \"video/quicktime,variant=iso:video/x-h264:audio/mpeg,mpegversion=1,layer=3\"\n\n"
+      "Render xges to WebM with 1920x1080 resolution:\n"
+      "$ ges-launch -l project.xges -o out.webm \\\n"
+      "             -f \"video/webm:video/x-raw,width=1920,height=1080->video/x-vp8:audio/x-vorbis\"\n\n"
+      "A preset name can be used by adding +presetname:\n"
+      "$ ges-launch -l project.xges -o out.webm \\\n"
+      "             -f \"video/webm:video/x-vp8+presetname:x-vorbis\"\n\n"
+      "The presence property of the profile can be specified with |<presence>:\n"
+      "$ ges-launch -l project.xges -o out.ogv \\\n"
+      "             -f \"application/ogg:video/x-theora|<presence>:audio/x-vorbis\"");
   g_option_context_add_main_entries (ctx, options, NULL);
   g_option_context_add_group (ctx, gst_init_get_option_group ());
 
@@ -736,8 +865,12 @@ main (int argc, gchar ** argv)
     exit (0);
   }
 
+  if (inspect_action_type)
+    return ges_validate_print_action_types ((const gchar **) argv + 1,
+        argc - 1);
+
   tried_uris = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-  if (((!load_path && (argc < 4)))) {
+  if (((!load_path && !scenario && (argc < 4)))) {
     g_printf ("%s", g_option_context_get_help (ctx, TRUE, NULL));
     g_option_context_free (ctx);
     exit (1);
@@ -746,10 +879,32 @@ main (int argc, gchar ** argv)
   g_option_context_free (ctx);
 
   /* Create the pipeline */
-  pipeline = create_pipeline (&timeline, load_path, argc - 1, argv + 1);
+  create_pipeline (&timeline, load_path, argc - 1, argv + 1, scenario);
   if (!pipeline)
     exit (1);
 
+  if (videosink != NULL) {
+    GError *err = NULL;
+    GstElement *sink = gst_parse_bin_from_description (videosink, TRUE, &err);
+    if (sink == NULL) {
+      GST_ERROR ("could not create the requested videosink %s (err: %s), "
+          "exiting", err ? err->message : "", videosink);
+      exit (1);
+    }
+    ges_pipeline_preview_set_video_sink (pipeline, sink);
+  }
+
+  if (audiosink != NULL) {
+    GError *err = NULL;
+    GstElement *sink = gst_parse_bin_from_description (audiosink, TRUE, &err);
+    if (sink == NULL) {
+      GST_ERROR ("could not create the requested audiosink %s (err: %s), "
+          "exiting", err ? err->message : "", audiosink);
+      exit (1);
+    }
+    ges_pipeline_preview_set_audio_sink (pipeline, sink);
+  }
+
   /* Setup profile/encoding if needed */
   if (smartrender || outputuri) {
     GstEncodingProfile *prof = NULL;
@@ -759,7 +914,14 @@ main (int argc, gchar ** argv)
           GES_PROJECT (ges_extractable_get_asset (GES_EXTRACTABLE (timeline)));
       const GList *profiles = ges_project_list_encoding_profiles (proj);
 
-      prof = profiles ? profiles->data : NULL;
+      if (profiles) {
+        prof = profiles->data;
+        if (encoding_profile)
+          for (; profiles; profiles = profiles->next)
+            if (strcmp (encoding_profile,
+                    gst_encoding_profile_get_name (profiles->data)) == 0)
+              prof = profiles->data;
+      }
     }
 
     if (!prof) {
@@ -801,22 +963,31 @@ main (int argc, gchar ** argv)
     g_timeout_add (1000 * thumbinterval, thumbnail_cb, pipeline);
   }
 
+  if (ges_validate_activate (GST_PIPELINE (pipeline), scenario,
+          &needs_set_state) == FALSE) {
+    g_error ("Could not activate scenario %s", scenario);
+    return 29;
+  }
+
   bus = gst_pipeline_get_bus (GST_PIPELINE (pipeline));
   gst_bus_add_signal_watch (bus);
   g_signal_connect (bus, "message", G_CALLBACK (bus_message_cb), mainloop);
 
-  if (load_path == NULL && gst_element_set_state (GST_ELEMENT (pipeline),
+  if (needs_set_state && gst_element_set_state (GST_ELEMENT (pipeline),
           GST_STATE_PLAYING) == GST_STATE_CHANGE_FAILURE) {
     g_error ("Failed to start the pipeline\n");
     return 1;
   }
-  g_timeout_add (100, (GSourceFunc) _print_position, NULL);
   g_main_loop_run (mainloop);
 
   gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_NULL);
 
-  gst_object_unref (pipeline);
+  validate_res = ges_validate_clean (GST_PIPELINE (pipeline));
+  if (seenerrors == FALSE)
+    seenerrors = validate_res;
 
   g_hash_table_unref (tried_uris);
+  g_ptr_array_unref (new_paths);
+
   return (int) seenerrors;
 }
